@@ -4,6 +4,4 @@ class DvcRenderException(Exception):
 
 class MissingPlaceholderError(DvcRenderException):
     def __init__(self, placeholder, template_type):
-        super().__init__(
-            f"{template_type} template has to contain '{placeholder}'."
-        )
+        super().__init__(f"{template_type} template has to contain '{placeholder}'.")
